@@ -70,6 +70,8 @@ public:
 
     const QString getName();
 
+    bool envelope( const QSimEnvelope& env );
+
 protected slots:
     void mainMenu();
     void mainMenuSelection( int id );
@@ -109,14 +111,31 @@ protected slots:
     void CoLPMenu( const QSimTerminalResponse& resp );
     void sendCoLRMenu();
     void CoLRMenu( const QSimTerminalResponse& resp );
+    void sendCNAPMenu();
+    void CNAPMenu( const QSimTerminalResponse& resp );
     void sendLanguageMenu();
     void languageMenu( const QSimTerminalResponse& resp );
     void sendUSSDMenu();
     void USSDMenu( const QSimTerminalResponse& resp );
+    void sendSMSMenu();
+    void smsMenuResp( const QSimTerminalResponse& resp );
+    void smsSetDestResp( const QSimTerminalResponse& resp );
+    void smsSetTextResp( const QSimTerminalResponse& resp );
+    void sendPollingMenu();
+    void pollingMenuResp( const QSimTerminalResponse& resp );
+    void sendTimersMenu();
+    void timersMenuResp( const QSimTerminalResponse& resp );
+    void timersCmdResp( const QSimTerminalResponse& resp );
+    void sendRefreshMenu();
+    void refreshMenuResp( const QSimTerminalResponse& resp );
+    void sendLocalInfoMenu();
+    void localInfoMenu( const QSimTerminalResponse& resp );
 
 private:
     int sticksLeft;
     bool immediateResponse;
+    QString smsDestNumber, smsText;
+    QString timerStatus;
 };
 
 #endif
